import React, { forwardRef, memo, useImperativeHandle } from 'react';
import { useEffect, useRef, useState } from 'react';
import { View } from 'react-native';
import SvgChart from './svgChart';
import * as echarts from 'echarts/core';
const ChartView = (_ref, ref) => {
  let {
    style,
    option,
    theme = 'light',
    height = _ref2 => {
      let {
        _height
      } = _ref2;
      return _height;
    },
    width = _ref3 => {
      let {
        _width
      } = _ref3;
      return _width;
    },
    lazyloading = true
  } = _ref;
  const chartRef = useRef(null);
  const [chartHeight, setChartHeight] = useState(0);
  const [chartWidth, setChartWidth] = useState(0);
  const [viewHeight, setViewHeight] = useState(0);
  const [viewWidth, setViewWidth] = useState(0);
  const [LazyLoadingFlg, setLazyLoadingFlg] = useState(lazyloading);
  const [chart, setChart] = useState();
  useEffect(() => {
    if (LazyLoadingFlg) {
      setTimeout(() => {
        setLazyLoadingFlg(false);
      }, 200);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  useEffect(() => {
    let _chart;
    if (chartWidth > 0 && chartHeight > 0) {
      if (chartRef.current) {
        if (chart) {
          chart.setOption(option ?? {});
        } else {
          // @ts-ignore
          _chart = echarts.init(chartRef.current, theme, {
            renderer: 'svg',
            height: chartHeight,
            width: chartWidth
          });
          _chart.setOption(option ?? {});
          setChart(_chart);
        }
      }
    }
  }, [option, theme, chartHeight, chartWidth, chart, chartRef]);
  useEffect(() => {
    if (chart) {
      chart.resize({
        height: chartHeight,
        width: chartWidth
      });
    }
  }, [chartHeight, chartWidth, chart]);
  useImperativeHandle(ref, () => chart, [chart]);
  useEffect(() => {
    if (typeof height === 'number' && height > 0) {
      setChartHeight(height);
    } else if (typeof height === 'function') {
      let _h = height({
        _width: viewWidth,
        _height: viewHeight
      });
      if (_h && _h > 0) setChartHeight(_h);
    } else {
      setChartHeight(viewHeight);
    }
  }, [height, viewHeight, viewWidth]);
  useEffect(() => {
    if (typeof width === 'number' && width > 0) {
      setChartWidth(width);
    } else if (viewWidth > 0 && typeof width === 'function') {
      let _w = width({
        _width: viewWidth,
        _height: viewHeight
      });
      if (_w) setChartWidth(_w);
    } else {
      setChartWidth(viewWidth);
    }
  }, [width, viewWidth, viewHeight]);
  return /*#__PURE__*/React.createElement(View, {
    onLayout: ev => {
      setViewHeight(Math.round(ev.nativeEvent.layout.height));
      setViewWidth(Math.round(ev.nativeEvent.layout.width));
    }
    // eslint-disable-next-line react-native/no-inline-styles
    ,
    style: [style, {
      flex: 1,
      height: '100%',
      width: '100%'
    }]
  }, !LazyLoadingFlg && /*#__PURE__*/React.createElement(SvgChart, {
    ref: chartRef
  }));
};
export default /*#__PURE__*/memo( /*#__PURE__*/forwardRef(ChartView));
//# sourceMappingURL=chartView.js.map